@@ -28,7 +28,8 @@ class FrontEnd():
         possible_config = (
             options.config,
             os.path.expanduser('~/.tvrenamr/config.yml'),
-            os.path.join(sys.path[0], 'config.yml'))
+            os.path.join(sys.path[0], 'config.yml')
+        )
 
         # get the first viable config from the list of possibles
         self.config = None
@@ -48,13 +49,13 @@ class FrontEnd():
 
         # determine type
         try:
-            file_list = self.__determine_type(path, options.recursive,
+            file_list = self._build_file_list(path, options.recursive,
                                                 options.ignore_filelist)
         except OSError:
             parser.error('\'%s\' is not a file or directory. Ruh Roe!' % path)
 
         if options.dry or options.debug:
-            self.__start_dry_run()
+            self._start_dry_run()
 
         # kick off a rename for each file in the list
         for details in file_list:
@@ -65,9 +66,9 @@ class FrontEnd():
                 log.info('')
 
         if options.dry or options.debug:
-            self.__stop_dry_run()
+            self._stop_dry_run()
 
-    def __determine_type(self, path, recursive=False, ignore_filelist=None):
+    def _build_file_list(self, path, recursive=False, ignore_filelist=None):
         """
         Determines which files need to be processed for renaming.
 
@@ -110,8 +111,7 @@ class FrontEnd():
 
         try:
             tv = TvRenamr(working, self.config, options.debug, options.dry)
-            episode = Episode()
-            episode.show, episode.season, episode.episode, episode.extension = tv.extract_details_from_file(filename, user_regex=options.regex)
+            episode = Episode(tv.extract_details_from_file(filename, user_regex=options.regex))
             if options.show:
                 episode.show = options.show
             if options.season:
@@ -119,32 +119,42 @@ class FrontEnd():
             if options.episode:
                 episode.episode = options.episode
 
-            episode.title = tv.retrieve_episode_name(episode, library=options.library, canonical=options.canonical)
-            episode.show = tv.format_show_name(episode.show, the=options.the, override=options.show_override)
-            path = tv.build_path(episode, rename_dir=options.rename_dir, organise=options.organise, format=options.output_format)
+            episode.title = tv.retrieve_episode_name(episode, library=options.library,
+                                                        canonical=options.canonical)
+
+            episode.show = tv.format_show_name(episode.show, the=options.the,
+                                                override=options.show_override)
+
+            path = tv.build_path(episode, rename_dir=options.rename_dir,
+                                    organise=options.organise, format=options.output_format)
+
             tv.rename(filename, path)
-        except (ConfigNotFoundException, NoNetworkConnectionException, NoMoreLibrariesException):
+        except (ConfigNotFoundException,
+                NoMoreLibrariesException,
+                NoNetworkConnectionException):
             if options.dry or options.debug:
-                self.__stop_dry_run()
-            exit()
-        except (EmptyEpisodeNameException, \
-                EpisodeAlreadyExistsInDirectoryException, \
-                EpisodeNotFoundException, \
-                IncorrectCustomRegularExpressionSyntaxException, \
-                OutputFormatMissingSyntaxException, ShowNotFoundException, \
-                UnexpectedFormatException, XMLEmptyException):
+                self._stop_dry_run()
+            sys.exit(1)
+        except (EmptyEpisodeNameException,
+                EpisodeAlreadyExistsInDirectoryException,
+                EpisodeNotFoundException,
+                IncorrectCustomRegularExpressionSyntaxException,
+                OutputFormatMissingSyntaxException,
+                ShowNotFoundException,
+                UnexpectedFormatException,
+                XMLEmptyException):
             pass
         except Exception as err:
             if options.debug:
                 log.critical(err)
             pass
 
-    def __start_dry_run(self):
+    def _start_dry_run(self):
         log.log(26, 'Dry Run beginning.')
         log.log(26, '-' * 70)
         log.log(26, '')
 
-    def __stop_dry_run(self):
+    def _stop_dry_run(self):
         log.log(26, '')
         log.log(26, '-' * 70)
         log.log(26, 'Dry Run complete. No files were harmed in the process.')
@@ -163,7 +173,6 @@ def run():
     else:
         FrontEnd(args)
 
-
 if __name__ == "__main__":
     run()
 
